@@ -1,11 +1,20 @@
 OC.L10N.register(
     "text",
     {
+    "The file was uploaded" : "Datne tika augšupielādēta",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Augšupielādētā datne pārsniedz php.ini norādīto upload_max_filesize vērtību",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
+    "The file was only partially uploaded" : "Datne tika augšupielādēta tikai daļēji",
     "No file was uploaded" : "Neviena datne netika augšupielādēta",
     "Missing a temporary folder" : "Trūkst pagaidu mapes",
+    "Could not write file to disk" : "Nevarēja ierakstīt datni diskā",
+    "A PHP extension stopped the file upload" : "PHP paplašinājums apturēja datnes augšupielādi",
+    "File not found" : "Datne nav atrasta",
     "Text" : "Teksts",
+    "Translate" : "Tulkot",
+    "Use current version" : "Izmantot pašreizējo versiju",
     "Guest" : "Viesis",
+    "Remove link" : "Noņemt saiti",
     "guest" : "viesis",
     "Offline" : "Bezsaistē",
     "Saving …" : "Saglabā ...",
@@ -14,20 +23,24 @@ OC.L10N.register(
     "Bold" : "Treknraksts",
     "Italic" : "Slīpraksts",
     "Strikethrough" : "Pārsvītrojums",
-    "Remove link" : "Noņemt saiti",
-    "Update link" : "Atjaunināt saiti",
-    "Translate" : "Tulkot",
-    "Select language" : "Izvēlies valodu",
-    "to" : "kam",
-    "Replace" : "Aizvietot",
-    "Source code" : "Izejas kods",
-    "Unsupported image type" : "Neatbalstīts attēla tips",
+    "Link" : "Saite",
+    "Action" : "Darbība",
     "Undo" : "Atsaukt",
     "Redo" : "Atcelt atsaukšanu",
+    "Cancel" : "Atcelt",
+    "URL" : "URL",
+    "Update link" : "Atjaunināt saiti",
+    "Select language" : "Atlasīt valodu",
+    "to" : "kam",
+    "Replace" : "Aizvietot",
+    "Edit" : "Labot",
+    "Source code" : "Izejas kods",
+    "Done" : "Pabeigts",
+    "Details" : "Detaļas",
     "Insert link" : "Ievietojiet saiti",
-    "Info" : "Info",
-    "Warning" : "Brīdinājums",
     "Command" : "Komanda",
-    "Edit" : "Rediģēt"
+    "Add folder description" : "Pievienot mapes aprakstu",
+    "Info" : "Info",
+    "Warning" : "Brīdinājums"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
