@@ -35,16 +35,17 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klik tombol berikut untuk menyetel ulang kata sandi Anda. Jika Anda tidak melakukan permintaan setel ulang kata sandi, abaikan surel ini.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klik tautan berikut untuk menyetel ulang kata sandi Anda. Jika Anda tidak melakukan permintaan setel ulang kata sandi, abaikan surel ini.",
     "Reset your password" : "Setel ulang kata sandi Anda",
+    "Internal error" : "Kesalahan internal",
     "Nextcloud Server" : "Server Nextcloud",
     "Some of your link shares have been removed" : "Beberapa tautan berbagi Anda telah dihapus",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Dikarenakan isu bug keamanan, kami perlu menghapus beberapa tautan berbagi Anda. Silakan lihat tautan berikut untuk informasi lebih lanjut.",
+    "Learn more ↗" : "Pelajari lebih lanjut ↗",
     "Preparing update" : "Mempersiapkan pembaruan",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Langkah perbaikan:",
     "Repair info:" : "Info perbaikan:",
     "Repair warning:" : "Peringatan perbaikan:",
     "Repair error:" : "Galat perbaikan:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Gunakan pembaruan di command line karena pembaruan otomatis di nonaktifkan di config.php. ",
     "Turned on maintenance mode" : "Hidupkan mode perawatan",
     "Turned off maintenance mode" : "Matikan mode perawatan",
     "Maintenance mode is kept active" : "Mode Pemeliharaan masih aktif",
@@ -60,29 +61,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (tidak kompatibel)",
     "The following apps have been disabled: %s" : "Aplikasi berikut telah dinonaktifkan: %s",
     "Already up to date" : "Sudah yang terbaru",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Peladen web Anda belum diatur sesuai untuk sinkronisasi berkas, karena antarmuka WebDAV tidak berfungsi.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP tidak disetel sesuai untuk melakukan kueri system environment variables. Pengujian dengan getenv(\"PATH\") hanya menghasilkan pesan kosong. ",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurasi baca-saja telah diaktifkan. Hal ini mencegah penyetelan beberapa konfigurasi via antarmuka web. Pada setiap proses pembaruan berikutnya, secara manual berkas tersebut perlu dibuat agar dapat ditulis.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Database Anda tidak dijalankan dengan isolasi transaksi level \"READ COMMITED\". Ini dapat menyebabkan masalah saat banyak tindakan dilakukan secara paralel.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Modul PHP \"fileinfo\" tidak ditemukan. Sangat dianjurkan untuk mengaktifkan modul ini, agar mendapatkan hasil deteksi terbaik tipe MIME. ",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Tidak memungkinan untuk eksekusi cron job via CLI. Kesalahan teknis berikut muncul:",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Anda sedang menjalankan PHP {version}. Tingkatkan versi PHP Anda untuk memanfaatkan kinerja {linkstart} dan pembaruan keamanan yang disediakan oleh Grup PHP ↗{linkend} segera setelah distribusi Anda mendukungnya.",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 adalah rilis terakhir yang mendukung PHP 7.3. Nextcloud 24 membutuhkan setidaknya PHP 7.4.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Fungsi PHP \"set_time_limit\" tidak tersedia. Hal ini dapat menyebabkan instalasi Anda, akibat eksekusi skrip terhenti ditengah-tengah. Mengaktifkan fungsi ini sangat dianjurkan.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP Anda tidak mendukung FreeType, yang akan menyebabkan gangguan pada foto profil dan pengaturan antarmuka.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Tidak ada index \"{indexName}\" pada tabel \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Pangkalan data kehilangan beberapa indeks. Berdasarkan fakta bahwa menambahkan indeks pada tabel yang besar membutuhkan waktu cukup lama, maka ini tidak dilakukan otomatis. Eksekusi \"occ db: add-missing-indexes\", untuk menambahkan indeks secara manual sementara instance tetap berjalan. Setelah itu dilakukan, maka kueri akan jauh lebih cepat.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Tidak ditemukan kolom opsional \"{columnName}\" pada tabel \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Pangkalan data kehilangan beberapa kolom opsional. Berdasarkan fakta bahwa menambahkannya pada tabel yang besar membutuhkan waktu cukup lama, maka ini tidak dilakukan otomatis. Eksekusi \"occ db: add-missing-columns\", untuk menambahkan kolom secara manual sementara instance tetap berjalan. Setelah itu dilakukan, maka beberapa fitur dapat meningkatkan daya tanggap atau kegunaan.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instance ini kehilangan beberapa modul PHP yang direkomendasikan. Sangat disarankan menggunakannya untuk peningkatan performa dan kompatibilitas.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite saat ini digunakan sebagai backend pangkalan data. Penggunaan instalasi skala lebih besar, kami sarankan agar beralih ke backend pangkalan data lainnya.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Hal ini sangat dianjurkan saat menggunakan klien desktop untuk sinkronisasi berkas.",
-    "The PHP memory limit is below the recommended value of 512MB." : "Batas memori PHP di bawah nilai yang disarankan yaitu 512MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Beberapa direktori dimiliki oleh pengguna berbeda dengan pengguna peladen web. Hal ini mungkin dikarenakan proses instalasi manual. Periksa hak akses direktori aplikasi berikut:",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Instance ini menggunakan penyimpanan objek berbasis S3 sebagai penyimpanan utama. Karena berkas unggahan disimpan sementara pada server, maka disarankan untuk memiliki ruang kosong 50 GB pada direktori sementara PHP. Periksa log untuk detail lengkap tentang lokasi dan ruang penyimpanan yang tersedia. Untuk memperbaikinya, ubah direktori sementara di php.ini atau sediakan lebih banyak ruang di jalur ipada lokasi tersebut.",
     "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP header \"{header}\" tidak sesuai tersetel seperti \"{expected}\". Hal ini berpotensi risiko keamanan dan kerahasiaan. Direkomendasikan untuk dapat disesuaikan mengikuti anjuran.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP header \"{header}\" tidak sesuai tersetel seperti \"{expected}\". Beberapa fitur mungkin akan tidak berfungsi dengan baik. Direkomendasikan untuk dapat disesuaikan mengikuti anjuran.",
     "unknown text" : "teks tidak diketahui",
     "Hello world!" : "Halo dunia!",
     "sunny" : "cerah",
@@ -99,111 +78,85 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Pembaruan gagal. Laporkan masalah ini ke <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitas Nextcloud</a>.",
     "Continue to {productName}" : "Lanjutkan ke {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Pembaruan berhasil. Mengarahkan Anda ke {productName} dalam hitungan detik."],
+    "Apps" : "Aplikasi",
     "More apps" : "Aplikasi lainnya",
+    "No" : "Tidak",
+    "Yes" : "Ya",
+    "Failed to add the public link to your Nextcloud" : "Gagal menambah tautan publik ke Nextcloud Anda",
+    "Start typing to search" : "Mulai mengetik untuk mencari",
+    "Today" : "Hari ini",
+    "Places" : "Tempat",
+    "People" : "Orang",
+    "Load more results" : "Muat lebih banyak hasil",
     "Log in" : "Masuk",
     "Logging in …" : "Log masuk...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Terdeteksi multipel percobaan log masuk tidak valid dari IP Anda. Pencekalan log masuk berikutnya dilakukan hingga 30 detik.",
     "Server side authentication failed!" : "Otentikasi dari sisi server gagal!",
-    "Please contact your administrator." : "Silakan hubungi administrator anda.",
+    "Please contact your administrator." : "Silakan hubungi administrator Anda.",
     "An internal error occurred." : "Terjadi kesalahan internal.",
     "Please try again or contact your administrator." : "Mohon coba lagi atau hubungi administrator Anda.",
     "Password" : "Kata Sandi",
-    "Wrong username or password." : "Nama pengguna atau kata sandi salah.",
-    "User disabled" : "Pengguna dinonaktifkan",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Terdeteksi multipel percobaan log masuk tidak valid dari IP Anda. Pencekalan log masuk berikutnya dilakukan hingga 30 detik.",
-    "Username or email" : "Nama pengguna atau email",
+    "Log in with a device" : "Log masuk dengan perangkat",
     "Your account is not setup for passwordless login." : "Akun Anda tidak diatur untuk masuk tanpa kata sandi.",
     "Browser not supported" : "Peramban tidak didukung",
     "Passwordless authentication is not supported in your browser." : "Otentikasi tanpa kata sandi tidak didukung peramban Anda.",
     "Your connection is not secure" : "Koneksi Anda tidak aman",
     "Passwordless authentication is only available over a secure connection." : "Otentikasi tanpa kata sandi hanya tersedia melalui koneksi aman.",
     "Reset password" : "Setel ulang kata sandi",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Pesan pengaturan ulang kata sandi telah dikirim ke alamat email akun ini. Jika Anda tidak menerimanya, periksa folder spam/sampah Anda atau minta bantuan administrator lokal Anda.",
-    "If it is not there ask your local administrator." : "Jika Anda tidak mendapatkannya, hubungi administrator Anda.",
-    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim email setel ulang. Silakan hubungi administrator Anda.",
+    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim surel setel ulang. Silakan hubungi administrator Anda.",
     "Password cannot be changed. Please contact your administrator." : "Kata sandi tidak dapat diubah. Silakan hubungi administrator Anda.",
     "Back to login" : "Kembali ke log masuk",
     "New password" : "Kata sandi baru",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Berkas Anda terenkripsi. Tidak memungkinkan untuk mendapatkan kembali data anda setelah kata sandi disetel ulang. Jika tidak yakin, silakan hubungi administrator Anda sebelum melanjutkan. Apa anda ingin melanjutkan?",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Berkas Anda terenkripsi. Tidak memungkinkan untuk mendapatkan kembali data Anda setelah kata sandi disetel ulang. Jika tidak yakin, silakan hubungi administrator Anda sebelum melanjutkan. Apa Anda ingin melanjutkan?",
     "I know what I'm doing" : "Saya tahu apa yang saya lakukan",
     "Resetting password" : "Menyetel ulang kata sandi",
+    "Schedule work & meetings, synced with all your devices." : "Penjadwalan rapat & pekerjaan, tersinkronisasi dengan gawai Anda.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Simpan info teman dan kolega Anda dalam satu tempat, tanpa membocorkan privat mereka.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplikasi klien surel sederhana, terintegrasi dengan Berkas, Kontak, dan Kalender.",
     "Recommended apps" : "Aplikasi terekomendasi",
     "Loading apps …" : "Memuat aplikasi ...",
     "Could not fetch list of apps from the App Store." : "Tidak dapat mengambil daftar aplikasi dari App Store.",
-    "Installing apps …" : "Instalasi aplikasi ...",
     "App download or installation failed" : "Unduh aplikasi atau gagal instalasi",
     "Cannot install this app because it is not compatible" : "Tidak dapat memasang aplikasi ini karena tidak kompatibel",
     "Cannot install this app" : "Tidak dapat memasang aplikasi ini",
     "Skip" : "Lewati",
-    "Install recommended apps" : "Instal aplikasi rekomendasi",
-    "Schedule work & meetings, synced with all your devices." : "Penjadwalan rapat & pekerjaan, tersinkronisasi dengan gawai Anda.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Simpan info teman dan kolega Anda dalam satu tempat, tanpa membocorkan privat mereka.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplikasi klien surel sederhana, terintegrasi dengan Berkas, Kontak, dan Kalender.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mengobrol, panggilan video, berbagi layar, rapat daring, dan konferensi web - melalui peramban dan menggunakan aplikasi pada gawai.",
-    "Forgot password?" : "Lupa kata sandi?",
-    "Log in with a device" : "Log masuk dengan perangkat",
-    "Back" : "Kembali",
-    "Edit Profile" : "Sunting profil",
-    "You have not added any info yet" : "Anda belum menambahkan info apa pun",
-    "{user} has not added any info yet" : "{user} belum menambahkan info apa pun",
-    "Reset search" : "Ulang pencarian",
-    "Start search" : "Mulai mencari",
-    "Search for {name} only" : "Cari {name} saja",
-    "No results for {query}" : "Tidak ada hasil untuk {query}",
-    "Press enter to start searching" : "Tekan enter untuk mulai mencari",
-    "Start typing to search" : "Mulai mengetik untuk mencari",
-    "Loading more results …" : "Memuat hasil lainnya…",
-    "Load more results" : "Muat lebih banyak hasil",
-    "Search" : "Cari",
-    "An error occurred while searching for {type}" : "Terjadi kesalahan saat mencari {type}",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Harap masukkan {minSearchLength} karakter atau lebih untuk mencari"],
-    "Search {types} …" : "Cari {types} …",
-    "Settings" : "Pengaturan",
-    "Could not load your contacts" : "Tidak dapat memuat kontak Anda",
-    "Search contacts …" : "Cari kontak ...",
-    "No contacts found" : "Kontak tidak ditemukan",
-    "Show all contacts …" : "Tampilkan semua kontak ...",
-    "Install the Contacts app" : "Instal aplikasi Kontak",
+    "Installing apps …" : "menginstal aplikasi ...",
+    "Install recommended apps" : "Instal aplikasi yang disarankan",
+    "Settings menu" : "Menu Pengaturan",
     "Loading your contacts …" : "Memuat kontak Anda ...",
     "Looking for {term} …" : "Mencari {term}",
-    "No" : "Tidak",
-    "Yes" : "Ya",
-    "No files in here" : "Tidak ada berkas disini",
-    "New folder" : "Folder baru",
-    "No more subfolders in here" : "Tidak ada lagi subfolder disini",
-    "Name" : "Nama",
-    "Size" : "Ukuran",
-    "Modified" : "Dimodifikasi",
-    "\"{name}\" is an invalid file name." : "\"{name}\" adalah nama berkas yang tidak sah.",
-    "File name cannot be empty." : "Nama berkas tidak boleh kosong.",
-    "\"/\" is not allowed inside a file name." : "\"/\" tidak diizinkan pada nama berkas.",
-    "\"{name}\" is not an allowed filetype" : "Tipe berkas \"{name}\" tidak diizinkan",
-    "{newName} already exists" : "{newName} sudah ada",
+    "Reset search" : "Ulang pencarian",
+    "Search contacts …" : "Cari kontak ...",
+    "Could not load your contacts" : "Tidak dapat memuat kontak Anda",
+    "No contacts found" : "Kontak tidak ditemukan",
+    "Show all contacts" : "Tampilkan semua kontak",
+    "Install the Contacts app" : "Instal aplikasi Kontak",
+    "Search" : "Cari",
+    "No results for {query}" : "Tidak ada hasil untuk {query}",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Harap masukkan {minSearchLength} karakter atau lebih untuk mencari"],
+    "An error occurred while searching for {type}" : "Terjadi kesalahan saat mencari {type}",
+    "Search for {name} only" : "Cari {name} saja",
+    "Loading more results …" : "Memuat hasil lainnya…",
+    "Forgot password?" : "Lupa kata sandi?",
+    "Back" : "Kembali",
+    "Search {types} …" : "Cari {types} …",
     "Choose" : "Pilih",
     "Copy" : "Salin",
     "Move" : "Pindah",
-    "Error loading file picker template: {error}" : "Kesalahan saat memuat templat berkas pemilih: {error}",
     "OK" : "OK",
-    "Error loading message template: {error}" : "Kesalahan memuat templat pesan: {error}",
     "read-only" : "hanya-baca",
     "_{count} file conflict_::_{count} file conflicts_" : ["{count} berkas konflik"],
     "One file conflict" : "Satu berkas konflik",
     "New Files" : "Berkas Baru",
     "Already existing files" : "Berkas sudah ada",
-    "Which files do you want to keep?" : "Berkas mana yang ingin anda pertahankan?",
-    "If you select both versions, the copied file will have a number added to its name." : "Jika anda memilih kedua versi, berkas yang disalin akan memiliki nomor yang ditambahkan sesuai namanya.",
+    "Which files do you want to keep?" : "Berkas mana yang ingin Anda pertahankan?",
+    "If you select both versions, the copied file will have a number added to its name." : "Jika Anda memilih kedua versi, berkas yang disalin akan memiliki nomor yang ditambahkan sesuai namanya.",
     "Cancel" : "Batal",
     "Continue" : "Lanjutkan",
     "(all selected)" : "(semua terpilih)",
     "({count} selected)" : "({count} terpilih)",
     "Error loading file exists template" : "Kesalahan memuat templat berkas yang sudah ada",
-    "Pending" : "Terutnda",
-    "Copy to {folder}" : "Salin ke {folder}",
-    "Move to {folder}" : "Pindah ke {folder}",
     "Saving …" : "Menyimpan ...",
-    "Authentication required" : "Diperlukan otentikasi",
-    "This action requires you to confirm your password" : "Aksi ini membutuhkan konfirmasi kata sandi Anda",
-    "Confirm" : "Konfirmasi",
-    "Failed to authenticate, try again" : "Gagal mengotentikasi, coba lagi",
     "seconds ago" : "beberapa detik yang lalu",
     "Connection to server lost" : "Koneksi ke server gagal",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tidak dapat memuat laman, muat ulang dalam %n detik"],
@@ -233,20 +186,14 @@ OC.L10N.register(
     "Collaborative tags" : "Tag kolaboratif",
     "No tags found" : "Tag tidak ditemukan",
     "Personal" : "Pribadi",
-    "Users" : "Pengguna",
-    "Apps" : "Aplikasi",
     "Admin" : "Admin",
     "Help" : "Bantuan",
     "Access forbidden" : "Akses ditolak",
-    "Profile not found" : "Profil tidak ditemukan",
-    "The profile does not exist." : "Profil tidak ada.",
+    "Page not found" : "Halaman tidak ditemukan",
     "Back to %s" : "Kembali ke %s",
-    "File not found" : "Berkas tidak ditemukan",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumen tidak ditemukan pada peladen. Mungkin sudah tidak dibagikan atau kedaluwarsa?",
     "Too many requests" : "Terlalu banyak permintaan",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ada terlalu banyak permintaan dari jaringan Anda. Coba lagi nanti atau hubungi administrator Anda jika ini adalah kesalahan.",
     "Error" : "Kesalahan",
-    "Previous" : "Sebelumnya",
     "Internal Server Error" : "Kesalahan Server Internal",
     "The server was unable to complete your request." : "Peladen tidak dapat menyelesaikan permintaan Anda.",
     "If this happens again, please send the technical details below to the server administrator." : "Jika terjadi lagi, silakan sampaikan detail di bawah kepada administrator.",
@@ -261,10 +208,8 @@ OC.L10N.register(
     "Line: %s" : "Baris: %s",
     "Trace" : "Jejak",
     "Security warning" : "Peringatan keamanan",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas Anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informasi bagaimana kesesuaian konfigurasi peladen Anda, silakan lihat <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasi</a>.",
-    "Create an <strong>admin account</strong>" : "Buat sebuah <strong>akun admin</strong>",
-    "Username" : "Nama pengguna",
     "Show password" : "Tampilkan kata sandi",
     "Storage & database" : "Penyimpanan & Basis data",
     "Data folder" : "Folder data",
@@ -272,7 +217,6 @@ OC.L10N.register(
     "Only %s is available." : "Hanya %s yang tersedia",
     "Install and activate additional PHP modules to choose other database types." : "Pasang dan aktifkan modul PHP tambahan untuk memilih tipe basis data lainnya.",
     "For more details check out the documentation." : "Untuk lebih rinci, periksa pada dokumentasi.",
-    "Database user" : "Pengguna basis data",
     "Database password" : "Kata sandi basis data",
     "Database name" : "Nama basis data",
     "Database tablespace" : "Tablespace basis data",
@@ -291,27 +235,23 @@ OC.L10N.register(
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikasi ini memerlukan JavaScript untuk dapat beroperasi dengan benar. Mohon {linkstart}aktifkan JavaScript{linkend} dan muat ulang halaman ini.",
     "Skip to main content" : "Lewati ke konten utama",
     "Skip to navigation of app" : "Lewati ke navigasi aplikasi",
+    "Go to %s" : "Pergi ke %s",
     "Get your own free account" : "Dapatkan akun gratis Anda",
-    "Contacts" : "Kontak",
-    "Contacts menu" : "Menu Kontak",
-    "Confirm your password" : "Konfirmasi kata sandi Anda",
     "Connect to your account" : "Hubungkan ke akun Anda",
     "Please log in before granting %1$s access to your %2$s account." : "Silakan log masuk sebelum mengizinkan %1$s mengakses akun %2$s Anda.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jika Anda tidak mencoba menyiapkan perangkat atau aplikasi baru, seseorang mencoba menipu Anda agar memberi mereka akses ke data Anda. Dalam hal ini jangan lanjutkan dan hubungi administrator sistem Anda.",
-    "App token" : "Token aplikasi",
     "Grant access" : "Berikan hak akses",
-    "Alternative log in using app token" : "Log masuk alternatif dengan token aplikasi",
     "Account access" : "Akses akun",
     "You are about to grant %1$s access to your %2$s account." : "Anda akan memberikan izin %1$s akses ke akun %2$s Anda.",
     "Account connected" : "Akun terhubung",
     "Your client should now be connected!" : "Klien sudah terhubung!",
     "You can close this window." : "Anda dapat menutup jendela ini.",
+    "Previous" : "Sebelumnya",
     "This share is password-protected" : "Berbagi ini dilindungi kata sandi",
-    "Please type in your email address to request a temporary password" : "Silakan ketik alamat email Anda untuk meminta kata sandi sementara",
-    "Email address" : "Alamat email",
+    "Please type in your email address to request a temporary password" : "Silakan ketik alamat surel Anda untuk meminta kata sandi sementara",
+    "Email address" : "Alamat surel",
     "Password sent!" : "Kata sandi terkirim!",
     "You are not authorized to request a password for this share" : "Anda tidak diizinkan untuk meminta kata sandi untuk pembagian ini",
-    "Go to %s" : "Pergi ke %s",
     "Two-factor authentication" : "Otentikasi Two-factor",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Peningkatan keamanan telah diaktifkan pada akun Anda. Pilih faktor-kedua untuk autentikasi:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Tidak dapat memuat salah satu dari metode autentikasi faktor-kedua. Silakan hubungi admin Anda.",
@@ -322,7 +262,7 @@ OC.L10N.register(
     "Use backup code" : "Gunakan kode cadangan",
     "Cancel login" : "Batalkan log masuk",
     "Enhanced security is enforced for your account. Choose which provider to set up:" : "Peningkatan keamanan diwajibkan untuk akun Anda. Pilih penyedia setelan:",
-    "Error while validating your second factor" : "Galat ketika memvalidasi faktor kedua anda",
+    "Error while validating your second factor" : "Galat ketika memvalidasi faktor kedua Anda",
     "Access through untrusted domain" : "Akses melalui domain tidak terpercaya",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Silakan hubungi administrator Anda. Apabila Anda adalah administrator dari instalasi ini, setel parameter \"trusted_domains\" pada config/config.php seperti contoh yang tersedia pada config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Info lebih lanjut mengenai pengaturan ini, dapat ditemukan pada %1$sdokumentasi%2$s.",
@@ -336,30 +276,19 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Untuk menghindari waktu habis dengan instalasi yang lebih besar, Anda bisa menjalankan perintah berikut dari direktori instalasi Anda:",
     "Detailed logs" : "Log detail",
     "Update needed" : "Pembaruan dibutuhkan",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Silakan gunakan command line updater, karena instalasi Anda memiliki pengguna lebih dari 50.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Lihat <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentasi</a> untuk panduan.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Saya paham jika melakukan proses pemutakhiran via antarmuka web, berisiko komunikasi terhenti dan kemungkinan kehilangan data. Saya punya cadangan dan paham bagaimana cara pemulihan, jika terjadi kegagalan.",
     "Upgrade via web on my own risk" : "Pemutakhiran via web adalah risiko saya",
     "Maintenance mode" : "Mode pemeliharaan",
     "This %s instance is currently in maintenance mode, which may take a while." : "Instansi %s ini sedang dalam modus pemeliharaan, mungkin memerlukan beberapa saat.",
     "This page will refresh itself when the instance is available again." : "Laman ini akan dimuat otomatis saat instalasi kembali tersedia.",
-    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem anda jika pesan ini terus muncul atau muncul tiba-tiba.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: Mengecek tabel %s",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Peladen ini tidak terhubung ke internet. Beberapa titik akhir tidak dapat terjangkau. Hal ini berarti beberapa fitur, seperti: pemasangan penyimpanan eksternal, notifikasi pembaruan atau instalasi aplikasi pihak ketiga tidak akan berfungsi. Mengakses berkas dari jarak jauh dan mengirim notifikasi surel keduanya tidak akan berfungsi. Hubungkan peladen ini ke internet, untuk dapat mendapatkan fitur-fitur tersebut.",
-    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 adalah rilis terakhir yang mendukung PHP 7.2. Nextcloud 21 membutuhkan setidaknya PHP 7.3.",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Data folder dan berkas Anda kemungkinan dapat diakses dari Internet secara langsung, dikarenakan berkas .htaccess tidak bekerja. Sangat dianjurkan Anda untuk menyetel peladen web, untuk mencegah hal tersebut terjadi. Atau pindahkan lokasi data Anda di luar root dokumen peladen web.",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP header \"{header}\" tidak memiliki \"{expected}\". Hal ini berpotensi risiko keamanan dan kerahasiaan. Direkomendasikan untuk dapat disesuaikan mengikuti anjuran.",
-    "Collaboratively edit office documents." : "Berkolaborasi edit dokumen perkantoran.",
-    "Local document editing back-end used by the Collabora Online app." : "Pengeditan dokumen lokal menggunakan aplikasi Collabora Online sebagai back-end.",
-    "restricted" : "terbatas",
-    "invisible" : "tersembunyi",
-    "More" : "Lainnya",
-    "More apps menu" : "Menu aplikasi lainnya",
-    "Settings menu" : "Menu Pengaturan",
-    "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
-    "Setup two-factor authentication" : "Setel autentikasi faktor-kedua",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Rilis komunitas Nextcloud ini tidak didukung dan pemberitahuan instan tidak tersedia.",
-    "You haven't added any info yet" : "Anda belum menambahkan info apa pun",
-    "{user} hasn't added any info yet" : "{user} belum menambahkan info apa pun"
+    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem Anda jika pesan ini terus muncul atau muncul tiba-tiba.",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mengobrol, panggilan video, berbagi layar, rapat daring, dan konferensi web - melalui peramban dan menggunakan aplikasi pada gawai.",
+    "You have not added any info yet" : "Anda belum menambahkan info apa pun",
+    "{user} has not added any info yet" : "{user} belum menambahkan info apa pun",
+    "Edit Profile" : "Sunting profil",
+    "Error loading message template: {error}" : "Kesalahan memuat templat pesan: {error}",
+    "Profile not found" : "Profil tidak ditemukan",
+    "The profile does not exist." : "Profil tidak ada."
 },
 "nplurals=1; plural=0;");
